@@ -1,30 +1,17 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: Mu yanru
-# Date  : 2019.2
-# Email : muyanru345@163.com
-###################################################################
 """
 MClickBrowserFilePushButton, MClickBrowserFileToolButton
 MClickBrowserFolderPushButton, MClickBrowserFolderToolButton
 Browser files or folders by selecting.
-
 MDragFileButton, MDragFolderButton
 Browser files or folders by dragging.
 """
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 # Import built-in modules
 import os
 
 # Import third-party modules
-from Qt import QtCore
-from Qt import QtWidgets
-import six
+from qtpy import QtCore
+from qtpy import QtWidgets
 
 # Import local modules
 from dayu_widgets import dayu_theme
@@ -35,23 +22,33 @@ from dayu_widgets.tool_button import MToolButton
 
 
 # NOTE PySide2 Crash without QObject wrapper
+
 # @Slot()
+
+
 def _slot_browser_file(self):
     filter_list = (
         "File(%s)" % (" ".join(["*" + e for e in self.get_dayu_filters()]))
         if self.get_dayu_filters()
         else "Any File(*)"
     )
+
     if self.get_dayu_multiple():
         r_files, _ = QtWidgets.QFileDialog.getOpenFileNames(
-            self, "Browser File", self.get_dayu_path(), filter_list
+            self,
+            "Browser File",
+            self.get_dayu_path(),
+            filter_list
         )
         if r_files:
             self.sig_files_changed.emit(r_files)
             self.set_dayu_path(r_files[0])
     else:
         r_file, _ = QtWidgets.QFileDialog.getOpenFileName(
-            self, "Browser File", self.get_dayu_path(), filter_list
+            self,
+            "Browser File",
+            self.get_dayu_path(),
+            filter_list
         )
         if r_file:
             self.sig_file_changed.emit(r_file)
@@ -59,10 +56,11 @@ def _slot_browser_file(self):
 
 
 # @Slot()
+
+
 def _slot_browser_folder(self):
-    r_folder = QtWidgets.QFileDialog.getExistingDirectory(
-        self, "Browser Folder", self.get_dayu_path()
-    )
+    title = "Browser Folder"
+    r_folder = QtWidgets.QFileDialog.getExistingDirectory(self, title, self.get_dayu_path())
     if r_folder:
         if self.get_dayu_multiple():
             self.sig_folders_changed.emit([r_folder])
@@ -73,13 +71,14 @@ def _slot_browser_folder(self):
 
 # @Slot()
 def _slot_save_file(self):
-    filter_list = (
-        "File(%s)" % (" ".join(["*" + e for e in self.get_dayu_filters()]))
-        if self.get_dayu_filters()
-        else "Any File(*)"
-    )
+    filter_list = "Any File(*)"
+    if self.get_dayu_filters():
+        extensions = [f"*{e}" for e in self.get_dayu_filters()]
+        filter_list = f"File({' '.join(extensions)})"
+
+    title = "Save File"
     r_file, _ = QtWidgets.QFileDialog.getSaveFileName(
-        self, "Save File", self.get_dayu_path(), filter_list
+        self, title, self.get_dayu_path(), filter_list
     )
     if r_file:
         self.sig_file_changed.emit(r_file)
@@ -98,7 +97,6 @@ class MClickBrowserFilePushButton(MPushButton):
         self.setProperty("multiple", multiple)
         self.clicked.connect(self.slot_browser_file)
         self.setToolTip(self.tr("Click to browser file"))
-
         self._path = None
         self._multiple = multiple
         self._filters = []
@@ -149,7 +147,7 @@ class MClickBrowserFilePushButton(MPushButton):
         self._multiple = value
 
     dayu_multiple = QtCore.Property(bool, get_dayu_multiple, set_dayu_multiple)
-    dayu_path = QtCore.Property(six.string_types[0], get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
     dayu_filters = QtCore.Property(list, get_dayu_filters, set_dayu_filters)
 
 
@@ -166,7 +164,6 @@ class MClickBrowserFileToolButton(MToolButton):
         self.icon_only()
         self.clicked.connect(self.slot_browser_file)
         self.setToolTip(self.tr("Click to browser file"))
-
         self._path = None
         self._multiple = multiple
         self._filters = []
@@ -214,10 +211,11 @@ class MClickBrowserFileToolButton(MToolButton):
         :param value: bool
         :return: None
         """
+
         self._multiple = value
 
     dayu_multiple = QtCore.Property(bool, get_dayu_multiple, set_dayu_multiple)
-    dayu_path = QtCore.Property(six.string_types[0], get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
     dayu_filters = QtCore.Property(list, get_dayu_filters, set_dayu_filters)
 
 
@@ -233,7 +231,6 @@ class MClickSaveFileToolButton(MToolButton):
         self.icon_only()
         self.clicked.connect(self.slot_browser_file)
         self.setToolTip(self.tr("Click to save file"))
-
         self._path = None
         self._multiple = multiple
         self._filters = []
@@ -268,7 +265,7 @@ class MClickSaveFileToolButton(MToolButton):
         """
         self._path = value
 
-    dayu_path = QtCore.Property(six.string_types[0], get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
     dayu_filters = QtCore.Property(list, get_dayu_filters, set_dayu_filters)
 
 
@@ -285,15 +282,14 @@ class MDragFileButton(MToolButton):
         self.setMouseTracking(True)
         self.text_under_icon()
         self.setText(text)
+
         size = dayu_theme.drag_size
         self.set_dayu_size(size)
         self.setIconSize(QtCore.QSize(size, size))
         self.set_dayu_svg("cloud_line.svg")
 
         self.clicked.connect(self.slot_browser_file)
-        self.setSizePolicy(
-            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
-        )
+        self.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
         self.setToolTip(self.tr("Click to browser file"))
 
         self._path = None
@@ -346,7 +342,7 @@ class MDragFileButton(MToolButton):
         self._multiple = value
 
     dayu_multiple = QtCore.Property(bool, get_dayu_multiple, set_dayu_multiple)
-    dayu_path = QtCore.Property(six.string_types[0], get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
     dayu_filters = QtCore.Property(list, get_dayu_filters, set_dayu_filters)
 
     def dragEnterEvent(self, event):
@@ -377,14 +373,12 @@ class MDragFileButton(MToolButton):
         for url in url_list:
             file_name = url.toLocalFile()
             if sys.platform == "darwin":
+                cmd = 'osascript -e \'get posix path of posix file "file://{0}"\''.format(file_name)
                 sub_process = subprocess.Popen(
-                    "osascript -e 'get posix path of posix file \"file://{}\" -- kthxbai'".format(
-                        file_name
-                    ),
+                    cmd,
                     stdout=subprocess.PIPE,
-                    shell=True,
+                    shell=True
                 )
-                # print sub_process.communicate()[0].strip()
                 file_name = sub_process.communicate()[0].strip()
                 sub_process.wait()
 
@@ -410,7 +404,6 @@ class MClickBrowserFolderPushButton(MPushButton):
         self.setProperty("multiple", multiple)
         self.clicked.connect(self.slot_browser_folder)
         self.setToolTip(self.tr("Click to browser folder"))
-
         self._path = None
         self._multiple = multiple
 
@@ -434,6 +427,7 @@ class MClickBrowserFolderPushButton(MPushButton):
         Get browser can select multiple file or not
         :return: bool
         """
+
         return self._multiple
 
     def set_dayu_multiple(self, value):
@@ -445,7 +439,7 @@ class MClickBrowserFolderPushButton(MPushButton):
         self._multiple = value
 
     dayu_multiple = QtCore.Property(bool, get_dayu_multiple, set_dayu_multiple)
-    dayu_path = QtCore.Property(six.string_types[0], get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
 
 
 @property_mixin
@@ -458,12 +452,10 @@ class MClickBrowserFolderToolButton(MToolButton):
 
     def __init__(self, multiple=False, parent=None):
         super(MClickBrowserFolderToolButton, self).__init__(parent=parent)
-
         self.set_dayu_svg("folder_line.svg")
         self.icon_only()
         self.clicked.connect(self.slot_browser_folder)
         self.setToolTip(self.tr("Click to browser folder"))
-
         self._path = None
         self._multiple = multiple
 
@@ -498,7 +490,7 @@ class MClickBrowserFolderToolButton(MToolButton):
         self._multiple = value
 
     dayu_multiple = QtCore.Property(bool, get_dayu_multiple, set_dayu_multiple)
-    dayu_path = QtCore.Property(six.string_types[0], get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
 
 
 @property_mixin
@@ -516,16 +508,14 @@ class MDragFolderButton(MToolButton):
         self.setMouseTracking(True)
         self.text_under_icon()
         self.set_dayu_svg("folder_line.svg")
+
         size = dayu_theme.drag_size
         self.set_dayu_size(size)
         self.setIconSize(QtCore.QSize(size, size))
         self.setText(self.tr("Click or drag folder here"))
         self.clicked.connect(self.slot_browser_folder)
-        self.setSizePolicy(
-            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
-        )
+        self.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
         self.setToolTip(self.tr("Click to browser folder or drag folder here"))
-
         self._path = None
         self._multiple = multiple
 
@@ -557,14 +547,16 @@ class MDragFolderButton(MToolButton):
         :param value: bool
         :return: None
         """
+
         self._multiple = value
 
     dayu_multiple = QtCore.Property(bool, get_dayu_multiple, set_dayu_multiple)
-    dayu_path = QtCore.Property(bool, get_dayu_path, set_dayu_path)
+    dayu_path = QtCore.Property(str, get_dayu_path, set_dayu_path)
 
     def dragEnterEvent(self, event):
         """Override dragEnterEvent. Validate dragged folders"""
         if event.mimeData().hasFormat("text/uri-list"):
+            # Get list of valid folders from dragged items
             folder_list = [
                 url.toLocalFile()
                 for url in event.mimeData().urls()
