@@ -1,34 +1,131 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-###################################################################
-# Author: Mu yanru
-# Date  : 2019.2
-# Email : muyanru345@163.com
-###################################################################
-
-# Import future modules
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # Import built-in modules
 from functools import partial
+import os
 import re
 
 # Import third-party modules
-from Qt import QtCore
-from Qt import QtGui
-from Qt import QtWidgets
-from Qt.QtCompat import isValid
-import six
+from qtpy import QtCore
+from qtpy import QtGui
+from qtpy import QtWidgets
 
 # Import local modules
-from dayu_widgets.line_edit import MLineEdit
 from dayu_widgets.mixin import property_mixin
 from dayu_widgets.popup import MPopup
+from dayu_widgets.line_edit import MLineEdit
 import dayu_widgets.utils as utils
 
 
+PYSIDE6 = os.environ.get("QT_API") == "pyside6"
+
+
+class CompatStyle(QtWidgets.QProxyStyle):
+    """PySide2 PySide6"""
+
+    def __init__(self, style=None):
+        super(CompatStyle, self).__init__(style)
+        self.style = style
+
+    @property
+    def State_None(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.State()
+        return QtWidgets.QStyle.State_None
+
+    @property
+    def State_Active(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.State.State_Active
+        return QtWidgets.QStyle.State_Active
+
+    @property
+    def State_Enabled(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.State.State_Enabled
+        return QtWidgets.QStyle.State_Enabled
+
+    @property
+    def State_DownArrow(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.State.State_DownArrow
+        return QtWidgets.QStyle.State_DownArrow
+
+    @property
+    def State_UpArrow(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.State.State_UpArrow
+        return QtWidgets.QStyle.State_UpArrow
+
+    @property
+    def PE_PanelMenu(self):
+        if PYSIDE6:
+            # 在PySide6中使用PE_PanelButtonCommand替代PE_Frame
+            # PE_PanelButtonCommand通常会填充背景
+            return QtWidgets.QStyle.PE_PanelButtonCommand
+        return QtWidgets.QStyle.PE_PanelMenu
+
+    @property
+    def PE_FrameMenu(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.PE_Frame
+        return QtWidgets.QStyle.PE_FrameMenu
+
+    @property
+    def CE_MenuEmptyArea(self):
+        if PYSIDE6:
+            return QtWidgets.QStyle.CE_ShapedFrame
+        return QtWidgets.QStyle.CE_MenuEmptyArea
+
+    @property
+    def CE_MenuItem(self):
+        return QtWidgets.QStyle.CE_MenuItem
+
+    @property
+    def CE_MenuScroller(self):
+        return QtWidgets.QStyle.CE_MenuScroller
+
+    @property
+    def PM_MenuPanelWidth(self):
+        return QtWidgets.QStyle.PM_MenuPanelWidth
+
+    @property
+    def PM_MenuHMargin(self):
+        return QtWidgets.QStyle.PM_MenuHMargin
+
+    @property
+    def PM_MenuVMargin(self):
+        return QtWidgets.QStyle.PM_MenuVMargin
+
+    @property
+    def MenuItemType_EmptyArea(self):
+        if PYSIDE6:
+            return QtWidgets.QStyleOptionMenuItem.MenuItemType.EmptyArea
+        return QtWidgets.QStyleOptionMenuItem.EmptyArea
+
+    @property
+    def CheckType_NotCheckable(self):
+        if PYSIDE6:
+            return QtWidgets.QStyleOptionMenuItem.CheckType.NotCheckable
+        return QtWidgets.QStyleOptionMenuItem.NotCheckable
+
+    @property
+    def MenuItemType_Scroller(self):
+        if PYSIDE6:
+            return QtWidgets.QStyleOptionMenuItem.MenuItemType.Scroller
+        return QtWidgets.QStyleOptionMenuItem.Scroller
+
+    def combine_states(self, *states):
+        if PYSIDE6:
+            result = QtWidgets.QStyle.State()
+            for state in states:
+                result |= state
+            return result
+        else:
+            result = 0
+            for state in states:
+                result |= state
+            return result
+
+
 @property_mixin
 class ScrollableMenuBase(QtWidgets.QMenu):
     """
@@ -43,10 +140,11 @@ class ScrollableMenuBase(QtWidgets.QMenu):
         super(ScrollableMenuBase, self).__init__(*args, **kwargs)
         self._maximumHeight = self.maximumHeight()
         self._actionRects = []
+        self._compat_style = CompatStyle(self.style())
+
+        self.scrollTimer = QtCore.QTimer(parent=self, interval=50, singleShot=True)
+        self.scrollTimer.timeout.connect(self.checkScroll)
 
-        self.scrollTimer = QtCore.QTimer(
-            self, interval=50, singleShot=True, timeout=self.checkScroll
-        )
         self.scrollTimer.setProperty("defaultInterval", 50)
         self.delayTimer = QtCore.QTimer(self, interval=100, singleShot=True)
 
@@ -82,33 +180,32 @@ class ScrollableMenuBase(QtWidgets.QMenu):
         size = QtCore.QSize()
         fm = self.fontMetrics()
         qfm = opt.fontMetrics
-        size.setWidth(
-            fm.boundingRect(QtCore.QRect(), QtCore.Qt.TextSingleLine, a.text()).width()
-        )
+        size.setWidth(fm.boundingRect(QtCore.QRect(), QtCore.Qt.TextSingleLine, a.text()).width())
         size.setHeight(max(fm.height(), qfm.height()))
-        self.defaultItemHeight = style.sizeFromContents(
-            style.CT_MenuItem, opt, size, self
-        ).height()
+        self.defaultItemHeight = style.sizeFromContents(QtWidgets.QStyle.CT_MenuItem, opt, size, self).height()
 
         if not count:
             self.setMaximumHeight(self._maximumHeight)
         else:
-            fw = style.pixelMetric(style.PM_MenuPanelWidth, None, self)
-            vmargin = style.pixelMetric(style.PM_MenuHMargin, opt, self)
+            pm_menu_panel_width = self._compat_style.PM_MenuPanelWidth
+            fw = style.pixelMetric(pm_menu_panel_width, None, self)
+            vmargin = style.pixelMetric(self._compat_style.PM_MenuVMargin, opt, self)
             scrollHeight = self.scrollHeight(style)
-            self.setMaximumHeight(
-                self.defaultItemHeight * count + (fw + vmargin + scrollHeight) * 2
+            max_height = (
+                self.defaultItemHeight * count
+                + (fw + vmargin + scrollHeight) * 2
             )
+            self.setMaximumHeight(max_height)
         self.dirty = True
 
     def scrollHeight(self, style):
-        return style.pixelMetric(style.PM_MenuScrollerHeight, None, self) * 2
+        height = style.pixelMetric(QtWidgets.QStyle.PixelMetric.PM_MenuScrollerHeight, None, self)
+        return height * 2
 
     def isScrollable(self):
-        return (
-            self.property("scrollable")
-            and self.height() < super(ScrollableMenuBase, self).sizeHint().height()
-        )
+        is_scrollable = self.property("scrollable")
+        size_hint = super(ScrollableMenuBase, self).sizeHint()
+        return is_scrollable and self.height() < size_hint.height()
 
     def checkScroll(self):
         pos = self.mapFromGlobal(QtGui.QCursor.pos())
@@ -130,11 +227,12 @@ class ScrollableMenuBase(QtWidgets.QMenu):
 
     def ensureVisible(self, action):
         style = self.style()
-        fw = style.pixelMetric(style.PM_MenuPanelWidth, None, self)
-        hmargin = style.pixelMetric(style.PM_MenuHMargin, None, self)
-        vmargin = style.pixelMetric(style.PM_MenuVMargin, None, self)
+        pm_menu_panel_width = self._compat_style.PM_MenuPanelWidth
+        fw = style.pixelMetric(pm_menu_panel_width, None, self)
+        h_margin = style.pixelMetric(self._compat_style.PM_MenuHMargin, None, self)
+        v_margin = style.pixelMetric(self._compat_style.PM_MenuVMargin, None, self)
         scrollHeight = self.scrollHeight(style)
-        extent = fw + hmargin + vmargin + scrollHeight
+        extent = fw + h_margin + v_margin + scrollHeight
         r = self.rect().adjusted(0, extent, 0, -extent)
         geo = self.translatedActionGeometry(action)
         if geo.top() < r.top():
@@ -156,9 +254,7 @@ class ScrollableMenuBase(QtWidgets.QMenu):
             for lastAction in reversed(self.actions()):
                 if lastAction.isVisible():
                     break
-            lastBottom = (
-                self.actionGeometry(lastAction).bottom() - newDelta + scrollHeight
-            )
+            lastBottom = self.actionGeometry(lastAction).bottom() - newDelta + scrollHeight
             if lastBottom < bottom:
                 newDelta -= bottom - lastBottom
             if newDelta == self.deltaY:
@@ -183,7 +279,7 @@ class ScrollableMenuBase(QtWidgets.QMenu):
         return hint
 
     def eventFilter(self, source, event):
-        if event.type() == event.Show:
+        if event.type() == QtCore.QEvent.Show:
             if self.isScrollable() and self.deltaY:
                 action = source.menuAction()
                 self.ensureVisible(action)
@@ -220,9 +316,7 @@ class ScrollableMenuBase(QtWidgets.QMenu):
         elif event.type() == event.MouseButtonRelease:
             pos = event.pos()
             self.scrollTimer.stop()
-            if not (
-                self.scrollUpRect.contains(pos) or self.scrollDownRect.contains(pos)
-            ):
+            if not (self.scrollUpRect.contains(pos) or self.scrollDownRect.contains(pos)):
                 action = self.actionAt(pos)
                 if action:
                     action.trigger()
@@ -259,7 +353,7 @@ class ScrollableMenuBase(QtWidgets.QMenu):
                 action = None
 
         self.setActiveAction(action)
-        if action and isValid(action) and not action.isSeparator():
+        if action and not action.isSeparator():
 
             def ensureVisible():
                 self.delayTimer.timeout.disconnect()
@@ -309,25 +403,28 @@ class ScrollableMenuBase(QtWidgets.QMenu):
     def resizeEvent(self, event):
         super(ScrollableMenuBase, self).resizeEvent(event)
 
-        style = self.style()
-        l, t, r, b = self.getContentsMargins()
-        fw = style.pixelMetric(style.PM_MenuPanelWidth, None, self)
-        hmargin = style.pixelMetric(style.PM_MenuHMargin, None, self)
-        vmargin = style.pixelMetric(style.PM_MenuVMargin, None, self)
-        leftMargin = fw + hmargin + l
-        topMargin = fw + vmargin + t
-        bottomMargin = fw + vmargin + b
-        contentWidth = self.width() - (fw + hmargin) * 2 - l - r
+        margins = self.contentsMargins()
+        l, t, r, b = margins.left(), margins.top(), margins.right(), margins.bottom()
 
-        scrollHeight = self.scrollHeight(style)
-        self.scrollUpRect = QtCore.QRect(
-            leftMargin, topMargin, contentWidth, scrollHeight
-        )
+        style = self.style()
+        pm_menu_panel_width = self._compat_style.PM_MenuPanelWidth
+        pm_menu_v_margin = self._compat_style.PM_MenuVMargin
+        fw = style.pixelMetric(pm_menu_panel_width, None, self)
+        h_margin = style.pixelMetric(self._compat_style.PM_MenuHMargin, None, self)
+        v_margin = style.pixelMetric(pm_menu_v_margin, None, self)
+
+        left_margin = fw + h_margin + l
+        top_margin = fw + v_margin + t
+        bottom_margin = fw + v_margin + b
+        content_width = self.width() - (fw + v_margin) * 2 - l - r
+        scroll_height = self.scrollHeight(style)
+
+        self.scrollUpRect = QtCore.QRect(left_margin, top_margin, content_width, scroll_height)
         self.scrollDownRect = QtCore.QRect(
-            leftMargin,
-            self.height() - scrollHeight - bottomMargin,
-            contentWidth,
-            scrollHeight,
+            left_margin,
+            self.height() - scroll_height - bottom_margin,
+            content_width,
+            scroll_height,
         )
 
     def paintEvent(self, event):
@@ -342,12 +439,12 @@ class ScrollableMenuBase(QtWidgets.QMenu):
 
         menuOpt = QtWidgets.QStyleOptionMenuItem()
         menuOpt.initFrom(self)
-        menuOpt.state = style.State_None
+        menuOpt.state = self._compat_style.State_None
         menuOpt.maxIconWidth = 0
         menuOpt.tabWidth = 0
-        style.drawPrimitive(style.PE_PanelMenu, menuOpt, qp, self)
+        style.drawPrimitive(self._compat_style.PE_PanelMenu, menuOpt, qp, self)
 
-        fw = style.pixelMetric(style.PM_MenuPanelWidth, None, self)
+        fw = style.pixelMetric(self._compat_style.PM_MenuPanelWidth, None, self)
         topEdge = self.scrollUpRect.bottom()
         bottomEdge = self.scrollDownRect.top()
         offset = self.offset()
@@ -373,7 +470,7 @@ class ScrollableMenuBase(QtWidgets.QMenu):
             opt = QtWidgets.QStyleOptionMenuItem()
             self.initStyleOption(opt, action)
             opt.rect = actionRect.translated(0, offset)
-            style.drawControl(style.CE_MenuItem, opt, qp, self)
+            style.drawControl(self._compat_style.CE_MenuItem, opt, qp, self)
         qp.restore()
 
         cursor = self.mapFromGlobal(QtGui.QCursor.pos())
@@ -385,52 +482,51 @@ class ScrollableMenuBase(QtWidgets.QMenu):
 
             scrollOpt = QtWidgets.QStyleOptionMenuItem()
             scrollOpt.initFrom(self)
-            scrollOpt.state = style.State_None
-            scrollOpt.state |= style.State_DownArrow if isDown else style.State_UpArrow
-            scrollOpt.checkType = scrollOpt.NotCheckable
+            scrollOpt.state = self._compat_style.State_None
+            scrollOpt.state |= self._compat_style.State_DownArrow if isDown else self._compat_style.State_UpArrow
+            scrollOpt.checkType = self._compat_style.CheckType_NotCheckable
             scrollOpt.maxIconWidth = scrollOpt.tabWidth = 0
             scrollOpt.rect = scrollRect
-            scrollOpt.menuItemType = scrollOpt.Scroller
+            scrollOpt.menuItemType = self._compat_style.MenuItemType_Scroller
             if enabled:
-                if scrollRect.contains(cursor):
-                    frame = QtWidgets.QStyleOptionMenuItem()
-                    frame.initFrom(self)
-                    frame.rect = scrollRect
-                    frame.state |= style.State_Selected | style.State_Enabled
-                    style.drawControl(style.CE_MenuItem, frame, qp, self)
+                frame = QtWidgets.QStyleOptionMenuItem()
+                frame.initFrom(self)
+                frame.rect = scrollRect
+                frame.state = self._compat_style.combine_states(self._compat_style.State_Active,
+                                                                self._compat_style.State_Enabled)
+                style.drawControl(self._compat_style.CE_MenuItem, frame, qp, self)
 
-                scrollOpt.state |= style.State_Enabled
+                scrollOpt.state = self._compat_style.combine_states(scrollOpt.state, self._compat_style.State_Enabled)
                 scrollOpt.palette.setCurrentColorGroup(QtGui.QPalette.Active)
             else:
                 scrollOpt.palette.setCurrentColorGroup(QtGui.QPalette.Disabled)
-            style.drawControl(style.CE_MenuScroller, scrollOpt, qp, self)
+            style.drawControl(self._compat_style.CE_MenuScroller, scrollOpt, qp, self)
 
         if fw:
             borderReg = QtGui.QRegion()
             borderReg |= QtGui.QRegion(QtCore.QRect(0, 0, fw, self.height()))
-            borderReg |= QtGui.QRegion(
-                QtCore.QRect(self.width() - fw, 0, fw, self.height())
-            )
+            borderReg |= QtGui.QRegion(QtCore.QRect(self.width() - fw, 0, fw, self.height()))
             borderReg |= QtGui.QRegion(QtCore.QRect(0, 0, self.width(), fw))
-            borderReg |= QtGui.QRegion(
-                QtCore.QRect(0, self.height() - fw, self.width(), fw)
-            )
+            borderReg |= QtGui.QRegion(QtCore.QRect(0, self.height() - fw, self.width(), fw))
             qp.setClipRegion(borderReg)
             emptyArea -= borderReg
             frame = QtWidgets.QStyleOptionFrame()
             frame.rect = rect
             frame.palette = self.palette()
-            frame.state = QtWidgets.QStyle.State_None
-            frame.lineWidth = style.pixelMetric(style.PM_MenuPanelWidth)
+            frame.state = self._compat_style.combine_states(self._compat_style.State_None,
+                                                            self._compat_style.State_Active,
+                                                            self._compat_style.State_Enabled)
+            frame.lineWidth = style.pixelMetric(self._compat_style.PM_MenuPanelWidth, None, self)
             frame.midLineWidth = 0
-            style.drawPrimitive(style.PE_FrameMenu, frame, qp, self)
+            style.drawPrimitive(self._compat_style.PE_FrameMenu, frame, qp, self)
 
         qp.setClipRegion(emptyArea)
-        menuOpt.state = style.State_None
-        menuOpt.menuItemType = menuOpt.EmptyArea
-        menuOpt.checkType = menuOpt.NotCheckable
+        menuOpt.state = self._compat_style.combine_states(self._compat_style.State_None,
+                                                          self._compat_style.State_Enabled)
+        menuOpt.menuItemType = self._compat_style.MenuItemType_EmptyArea
+        menuOpt.checkType = self._compat_style.CheckType_NotCheckable
         menuOpt.rect = menuOpt.menuRect = rect
-        style.drawControl(style.CE_MenuEmptyArea, menuOpt, qp, self)
+        style.drawControl(self._compat_style.CE_MenuEmptyArea, menuOpt, qp, self)
 
 
 @property_mixin
@@ -439,13 +535,13 @@ class SearchableMenuBase(ScrollableMenuBase):
         super(SearchableMenuBase, self).__init__(*args, **kwargs)
         self.search_popup = MPopup(self)
         self.search_popup.setVisible(False)
-        self.search_bar = MLineEdit(self)
+        self.search_bar = MLineEdit(parent=self)
         self.search_label = QtWidgets.QLabel()
 
         self.search_bar.textChanged.connect(self.slot_search_change)
-        self.search_bar.keyPressEvent = partial(
-            self.search_key_event, self.search_bar.keyPressEvent
-        )
+        search_key_event_partial = partial(self.search_key_event,
+                                           self.search_bar.keyPressEvent)
+        self.search_bar.keyPressEvent = search_key_event_partial
         self.aboutToHide.connect(lambda: self.search_bar.setText(""))
 
         layout = QtWidgets.QVBoxLayout()
@@ -463,10 +559,10 @@ class SearchableMenuBase(ScrollableMenuBase):
         key = event.key()
         # NOTES: support menu original key event on search bar
         if key in (
-            QtCore.Qt.Key_Up,
-            QtCore.Qt.Key_Down,
-            QtCore.Qt.Key_Return,
-            QtCore.Qt.Key_Enter,
+                QtCore.Qt.Key_Up,
+                QtCore.Qt.Key_Down,
+                QtCore.Qt.Key_Return,
+                QtCore.Qt.Key_Enter,
         ):
             super(SearchableMenuBase, self).keyPressEvent(event)
         elif key == QtCore.Qt.Key_Tab:
@@ -480,7 +576,7 @@ class SearchableMenuBase(ScrollableMenuBase):
         self.search_bar.setPlaceholderText(value)
 
     def _set_search_re(self, value):
-        if not isinstance(value, six.text_type):
+        if not isinstance(value, str):
             raise TypeError("`search_re` property should be a string type")
 
     def slot_search_change(self, text):
@@ -555,11 +651,11 @@ class MMenu(SearchableMenuBase):
         self.set_data(data_list)
 
     def set_value(self, data):
-        assert isinstance(data, (list, six.string_types, six.integer_types, float))
+        assert isinstance(data, (list, str, int, float))
         # if isinstance(data, int):
         #     action = self._action_group.actions()[data]
         #     data = action.property('value')
-        if self.property("cascader") and isinstance(data, six.string_types):
+        if self.property("cascader") and isinstance(data, str):
             data = data.split(self.property("separator"))
         self.setProperty("value", data)
 
@@ -579,15 +675,13 @@ class MMenu(SearchableMenuBase):
             menu = MMenu(title=data_dict.get("label"), parent=self)
             menu.setProperty("value", data_dict.get("value"))
             parent_menu.addMenu(menu)
-            if not (parent_menu is self):
+            if parent_menu is not self:
                 # 用来将来获取父层级数据
                 menu.setProperty("parent_menu", parent_menu)
             for i in data_dict.get("children"):
                 self._add_menu(menu, i)
         else:
-            action = self._action_group.addAction(
-                utils.display_formatter(data_dict.get("label"))
-            )
+            action = self._action_group.addAction(utils.display_formatter(data_dict.get("label")))
             action.setProperty("value", data_dict.get("value"))
             action.setCheckable(True)
             # 用来将来获取父层级数据
@@ -597,10 +691,8 @@ class MMenu(SearchableMenuBase):
     def set_data(self, option_list):
         assert isinstance(option_list, list)
         if option_list:
-            if all(isinstance(i, six.string_types) for i in option_list):
-                option_list = utils.from_list_to_nested_dict(
-                    option_list, sep=self.property("separator")
-                )
+            if all(isinstance(i, str) for i in option_list):
+                option_list = utils.from_list_to_nested_dict(option_list, sep=self.property("separator"))
             if all(isinstance(i, (int, float)) for i in option_list):
                 option_list = [{"value": i, "label": str(i)} for i in option_list]
         # 全部转换成 dict 类型的 list
@@ -629,11 +721,7 @@ class MMenu(SearchableMenuBase):
             if self._action_group.isExclusive():
                 selected_data = current_data
             else:
-                selected_data = [
-                    act.property("value")
-                    for act in self._action_group.actions()
-                    if act.isChecked()
-                ]
+                selected_data = [act.property("value") for act in self._action_group.actions() if act.isChecked()]
         self.set_value(selected_data)
         self.sig_value_changed.emit(selected_data)
 
